import ctypes
import os.path

import numpy as np
from importlib_metadata import version

try:
    __version__ = version(__name__)
except Exception:
    pass


_so = ctypes.CDLL(os.path.join(os.path.abspath(os.path.dirname(__file__)), "_GPUSurfaceErode.so"))

# _so_speed = ctypes.CDLL(os.path.join(os.path.abspath(os.path.dirname(__file__)), "GPURegiongrowth_speed.so"))


def runSurfaceErode(imagedataNp, erode_iterations, interface=False, gpu=0):
    imagedataNp = imagedataNp.astype("uint8")
    print(f"image shape: {imagedataNp.shape}")
    depth = imagedataNp.shape[0]
    height = imagedataNp.shape[1]
    width = imagedataNp.shape[2]
    imagedataNpPtr = imagedataNp.ctypes.data_as(ctypes.POINTER(ctypes.c_uint8))
    print("enter surface erode cuda code!")
    _so.SurfaceErodeEntrance(
        imagedataNpPtr,
        width,
        height,
        depth,
        erode_iterations,
        interface,
        gpu,
    )
    imagedataNp = np.ctypeslib.as_array(imagedataNpPtr, shape=imagedataNp.shape)
    return imagedataNp



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['surface_erode']

package_data = \
{'': ['*'], 'surface_erode': ['src/*']}

install_requires = \
['importlib-metadata>=5.0.0,<6.0.0', 'numpy>=1.20.0,<2.0.0']

setup_kwargs = {
    'name': 'surface-erode',
    'version': '0.1.0',
    'description': 'erode medical image surface',
    'long_description': '',
    'author': '安兴乐',
    'author_email': 'anxingle@163.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
